summaryrefslogtreecommitdiffstats
path: root/tdeparts/mainwindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeparts/mainwindow.h')
-rw-r--r--tdeparts/mainwindow.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdeparts/mainwindow.h b/tdeparts/mainwindow.h
index b99527c00..4619a72cc 100644
--- a/tdeparts/mainwindow.h
+++ b/tdeparts/mainwindow.h
@@ -41,15 +41,15 @@ class MainWindowPrivate;
* and don't forget to call setXMLFile() in the inherited constructor.
*
* It implements all internal interfaces in the case of a
* KMainWindow as host: the builder and servant interface (for menu
* merging).
*/
-class KPARTS_EXPORT MainWindow : public KMainWindow, virtual public PartBase
+class KPARTS_EXPORT MainWindow : public TDEMainWindow, virtual public PartBase
{
Q_OBJECT
public:
/**
* Constructor, same signature as KMainWindow.
*/
#ifdef qdoc
MainWindow( TQWidget* parent, const char *name = 0L, WFlags f = WType_TopLevel | WDestructiveClose );
@@ -65,7 +65,7 @@ class KPARTS_EXPORT MainWindow : public KMainWindow, virtual public PartBase
MainWindow( const char *name = 0L, WFlags f = (WFlags)WDestructiveClose );
#endif
/**
* Constructor with creation flags, see KMainWindow.
* @since 3.2
*/
#ifdef qdoc
@@ -41,15 +41,15 @@ class MainWindowPrivate;
*
* It implements all internal interfaces in the case of a
- * KMainWindow as host: the builder and servant interface (for menu
+ * TDEMainWindow as host: the builder and servant interface (for menu
* merging).
*/
@@ -41,15 +41,15 @@ class MainWindowPrivate;
public:
/**
- * Constructor, same signature as KMainWindow.
+ * Constructor, same signature as TDEMainWindow.
*/
#ifdef qdoc
@@ -65,7 +65,7 @@ class KPARTS_EXPORT MainWindow : public KMainWindow, virtual public PartBase
#endif
/**
- * Constructor with creation flags, see KMainWindow.
+ * Constructor with creation flags, see TDEMainWindow.
* @since 3.2
*/